@@ -738,7 +738,8 @@ class InstallProgress(base.InstallProgress):
 			term.RESTORE_TERM in rawline
 			or term.DISABLE_ALT_SCREEN in rawline
 			or self.conf_end(rawline)
-		):
+			# Fix for Dialog Debconf Frontend https://gitlab.com/volian/nala/-/issues/211
+		) and term.ENABLE_ALT_SCREEN not in rawline:
 			self.raw = False
 			self.bug_list = False
 			term.restore_mode()
@@ -812,7 +813,7 @@ def format_version(match: list[str], line: str) -> str:
 	"""Format version numbers."""
 	for ver in match:
 		version = ver[1:-1]
-		if version[0].isdigit():
+		if version and version[0].isdigit():
 			new_ver = ver.replace(version, color(version, "BLUE"))
 			new_ver = re.sub(PARENTHESIS_PATTERN, paren_color, new_ver)
 			line = line.replace(ver, new_ver)
